@@ -37,7 +37,7 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
     def __init__(self):
         super(MayaSceneParser, self).__init__()
 
-    def parse(self, file_path=None):
+    def parse(self, file_path=None, show_dialogs=True):
         """
         Parses all the contents of the given file path looking for file paths
 
@@ -65,7 +65,7 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
             return list()
 
         with open(file_path, 'rb') as file_object:
-            parser.parse(file_object=file_object)
+            parser.parse(file_object=file_object, show_dialogs=show_dialogs)
 
         parsed_file_paths = [utils.clean_path(parsed_path) for parsed_path in parser.get_depend_paths()]
         if file_path in parsed_file_paths:
@@ -123,12 +123,20 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
                 continue
             file_path_editors[dir_name] = file_path_editor
 
+        converted_file_paths = list()
         for dir_name, file_path_editor in file_path_editors.items():
+            if not artella.DccPlugin().is_artella_path(dir_name):
+                continue
             i = 0
             while i < len(file_path_editor):
                 file_name = file_path_editor[i]
                 node_attr_name = file_path_editor[i + 1]
-                i += 2
+                try:
+                    reference_file_path = maya_utils.get_reference_file(node_attr_name, unresolved_name=True)
+                    if artella.DccPlugin().is_path_translated(reference_file_path):
+                        continue
+                finally:
+                    i += 2
                 maya_dir = artella.DccPlugin().translate_path(dir_name)
                 maya_file_path = utils.clean_path(os.path.join(dir_name, file_name))
                 translated_path = utils.clean_path(os.path.join(maya_dir, file_name))
@@ -139,26 +147,19 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
                 res = self._update_attr_path(node_attr_name, converted_path)
                 if not res:
                     valid_update = False
+                converted_file_paths.append(translated_path)
+                converted_file_paths.append(converted_path)
 
-        return valid_update
+        return valid_update, converted_file_paths
 
     def _update_attr_path(self, node_attr_name, file_path):
 
         node_name = node_attr_name.split('.')[0]
 
         if maya_utils.is_reference_node(node_name):
-            is_loaded = maya_utils.is_reference_loaded(node_name)
             valid_update = True
-            if is_loaded:
-                try:
-                    maya_utils.unload_reference(node_name)
-                except RuntimeError as exc:
-                    logger.error(
-                        'Encountered an error while attempting to unload reference file: "{}" | {}'.format(
-                            node_name, exc))
-                    valid_update = False
             try:
-                maya_utils.load_reference(file_path, node_name)
+                maya_utils.replace_reference(node_name, file_path)
             except RuntimeError as exc:
                 logger.error(
                     'Encountered an error while attempting to load reference file "{}" '
@@ -329,26 +330,31 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
             """
 
             self._stream = file_object
-            file_name = os.path.basename(self._stream.name)
+            # file_name = os.path.basename(self._stream.name)
 
-            if show_dialogs and qtutils.QT_AVAILABLE:
-                self._progress_splash = splash.ProgressSplashDialog()
-                self._progress_splash.set_progress_text('Please wait ...'.format(file_name))
-                self._progress_splash.start()
-
-            value = 0
+            # if show_dialogs and qtutils.QT_AVAILABLE:
+            #     self._progress_splash = splash.ProgressSplashDialog()
+            #     self._progress_splash.set_progress_text('Please wait ...'.format(file_name))
+            #     self._progress_splash.start()
+            #
+            # value = 0
             while self._parse_next_command():
-                value += 1
-                if value > 250:
-                    next_index = self._progress_splash.get_progress_value() + 1
-                    if next_index > 100:
-                        next_index = 1
-                    self._progress_splash.set_progress_value(next_index, 'Parsing file: {}'.format(file_name))
-                    QtWidgets.QApplication.instance().processEvents()
-                    value = 0
+                pass
 
-            if self._progress_splash:
-                self._progress_splash.close()
+            self._stream = None
+
+            #     if self._progress_splash:
+            #         value += 1
+            #         if value > 250:
+            #             next_index = self._progress_splash.get_progress_value() + 1
+            #             if next_index > 100:
+            #                 next_index = 1
+            #             self._progress_splash.set_progress_value(next_index, 'Parsing file: {}'.format(file_name))
+            #             QtWidgets.QApplication.instance().processEvents()
+            #             value = 0
+            #
+            # if self._progress_splash:
+            #     self._progress_splash.close()
 
         def _parse_next_command(self):
             """
@@ -389,9 +395,10 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
             :return:
             """
 
+            pass
+
             command, _, lines[0] = lines[0].partition(' ')
             command = command.lstrip()
-
             if not self.has_command(command):
                 return None
 
@@ -449,7 +456,7 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
         # PARSE
         # ==============================================================================================================
 
-        def parse(self, file_object):
+        def parse(self, file_object, show_dialogs=True):
             """
             Parses all the contents of the given file path looking for file paths
 
@@ -484,3 +491,9 @@ class MayaSceneParser(parser.AbstractSceneParser, object):
 
 
 register.register_class('Parser', MayaSceneParser)
+
+
+if __name__ == '__main__':
+    file_paths = [r"D:\shorts\artella-files\06 Flight Assets\06 Flight Assets\Arc Dragon\arcTheDragon_v1.61.ma"]
+    for file_path in file_paths:
+        print(MayaSceneParser().parse(file_path))
