@@ -8,6 +8,7 @@ Module that contains Maya DCC plugin specific implementation
 from __future__ import print_function, division, absolute_import
 
 import os
+import json
 import logging
 
 import maya.cmds as cmds
@@ -35,6 +36,34 @@ class ArtellaMayaPlugin(dccplugin.ArtellaDccPlugin, object):
 
         self._references_found = list()
 
+    def get_version(self, force_update=False):
+        """
+        Returns current DCC plugin version
+
+        :param bool force_update: Where or not force the update of the current Artella DCC plugin version
+        :return: Version in string format (MAJOR.MINOR.PATH) of the current Artella DCC plugin
+        :rtype: str or None
+        """
+
+        plugin_version = super(ArtellaMayaPlugin, self).get_version(force_update=force_update)
+
+        if not plugin_version or force_update:
+            version_var = self.get_version_variable_name()
+            artella_path = artella.__path__[0]
+            version_file_path = os.path.join(os.path.dirname(artella_path), 'plugin-version.json')
+            if os.path.isfile(version_file_path):
+                try:
+                    with open(version_file_path) as fh:
+                        version_data = json.load(fh)
+                        version_found = version_data.get('version', None)
+                        if version_found:
+                            os.environ[version_var] = str(version_found)
+                except Exception as exc:
+                    logger.error('Impossible to retrieve Artella {} Plugin version data: {}!'.format(dcc.name(), exc))
+            plugin_version = os.environ.get(version_var, None)
+
+        return plugin_version
+
     def init(self, dev=False, show_dialogs=True, create_menu=True, create_callbacks=True, *args, **kwargs):
         """
         Initializes Artella DCC plugin
@@ -73,8 +102,14 @@ class ArtellaMayaPlugin(dccplugin.ArtellaDccPlugin, object):
         Internal function that is called after update paths functionality is over.
         """
 
-        maya_utils.reload_textures()
-        maya_utils.reload_dependencies()
+        files_updated = kwargs.get('files_updated', list())
+        if not files_updated:
+            return
+
+        maya_utils.reload_textures(files_updated)
+
+        # Dependencies are already reloaded during update paths process
+        # maya_utils.reload_dependencies(files_updated)
 
     # ==============================================================================================================
     # FUNCTIONS
@@ -203,12 +238,11 @@ class ArtellaMayaPlugin(dccplugin.ArtellaDccPlugin, object):
         if self.is_artella_path():
             self.validate_environment_for_callback('BeforeReferenceCheck')
 
-        # NOTE: With this code we can force the update of file paths when opening a reference file.
-        # For now it's disabled because it's something that maybe it's not interesting from an user perspective.
-
-        # raw_full_name = maya_file.rawFullName()
-        # convert_path = artella.DccPlugin().convert_path(raw_full_name)
-        # maya_file.setRawFullName(convert_path)
+            raw_full_name = maya_file.rawFullName()
+            if not artella.DccPlugin().is_path_translated(
+                    raw_full_name) and artella.DccPlugin().is_artella_path(raw_full_name):
+                convert_path = artella.DccPlugin().convert_path(raw_full_name)
+                maya_file.setRawFullName(convert_path)
 
         OpenMaya.MScriptUtil.setBool(retcode, True)
 
